local AlertMe = {}
local settings = {
  speed = 0.06, -- A lower number animates faster.
  numberOfFlashes = 2, -- Number of times to flash the alert on the screen. Useful for people who have a lot going on. NOTE: THIS CAN NOW BE ACCESS FROM WITHIN THE GAME BY USING /alertme show
  backgroundOpacity = .2, -- The intensity of the flashing background. NOTE: THIS CAN NOW BE ACCESS FROM WITHIN THE GAME BY USING /alertme show
  opacity = 0, -- Starting opacity, this shouldn't be changed.
  combat_left_texture = "combat_alert_left.png", -- Change this to whatever texture you want. Just put it in the root folder for the addon.
  combat_right_texture = "combat_alert_right.png", -- Change this to whatever texture you want. Just put it in the root folder for the addon.
  exit_combat_left_texture = "exit_combat_alert_left.png", -- Change this to whatever texture you want. Just put it in the root folder for the addon.
  exit_combat_right_texture = "exit_combat_alert_right.png", -- Change this to whatever texture you want. Just put it in the root folder for the addon.
  texture_height = 664, -- Change this to match your texture.
  texture_width = 169,  -- Change this to match your texture.
  height = UIParent:GetHeight(), -- This should be left as is.
  width = UIParent:GetWidth(),  -- This should be left as is.
  show_background = true, -- The fullscreen background.
  ident = "AlertMe" -- Just the identifier for the addon.
}

print("AlertMe loaded. Type '/alertme show' to bring up the configuration window and '/alertme hide' to hide it.")
print("Current resolution is: "..settings.width .. " x " .. settings.height)


alert = UI.CreateContext("Context")

-- Configuration Window
local configWindow = UI.CreateFrame("RiftWindow", "Configuration", alert)
configWindow:SetTitle("AlertMe Configuration")
configWindow:SetPoint("CENTER", UIParent, "CENTER")
configWindow:SetHeight(300)
configWindow:SetWidth(300)
configWindow:SetVisible(false)

local nofText = UI.CreateFrame("Text", "nofText", configWindow)
nofText:SetPoint("TOPLEFT", configWindow, "TOPLEFT", 25, 60)


local nofInput = UI.CreateFrame("RiftSlider", "numOfFlashes", configWindow)
nofInput:SetWidth(100)
nofInput:SetHeight(20)
nofInput:SetPoint("TOPLEFT", configWindow, "TOPLEFT", 25, 85)
nofInput:SetRange(1, 5)
nofInput:SetPosition(settings.numberOfFlashes)
nofText:SetText("Number of Flashes: " .. tostring(nofInput:GetPosition()))

local button = UI.CreateFrame("RiftButton", "SubmitButton", configWindow)
button:SetText("Save")
button:SetPoint("BOTTOMCENTER", configWindow, "BOTTOMCENTER", -70, -20)

local exitButton = UI.CreateFrame("RiftButton", "ExitButton", configWindow)
exitButton:SetText("Exit")
exitButton:SetPoint("BOTTOMCENTER", configWindow, "BOTTOMCENTER", 70, -20)

local showBackgroundText = UI.CreateFrame("Text", "BGText", configWindow)
showBackgroundText:SetText("Show fullscreen background?")
showBackgroundText:SetPoint("TOPLEFT", configWindow, "TOPLEFT", 25, 105)

local showBackground = UI.CreateFrame("RiftCheckbox", "Checkbox", configWindow)
showBackground:SetPoint("TOPLEFT", configWindow, "TOPLEFT", 25, 125)

alertFrame = UI.CreateFrame("Frame", "alertFrame", alert)
alertFrame:SetPoint("CENTERLEFT", UIParent, "CENTERLEFT")
alertFrame:SetAlpha(0)
alertFrame:SetBackgroundColor(1,0,0,.2)
alertFrame:SetVisible(false)
alertFrame:SetHeight(settings.height)
alertFrame:SetWidth(settings.width)

alertFrameLeft = UI.CreateFrame("Texture", "alertFrameLeft", alertFrame)
alertFrameLeft:SetTexture(settings.ident, settings.combat_left_texture)
alertFrameLeft:SetPoint("CENTERLEFT", alertFrame, "CENTERLEFT")
alertFrameLeft:SetWidth(settings.texture_width)
alertFrameLeft:SetHeight(settings.texture_height)

alertFrameRight = UI.CreateFrame("Texture", "alertFrameRight", alertFrame)
alertFrameRight:SetTexture(settings.ident, settings.combat_right_texture)
alertFrameRight:SetPoint("CENTERRIGHT", alertFrame, "CENTERRIGHT")
alertFrameRight:SetWidth(settings.texture_width)
alertFrameRight:SetHeight(settings.texture_height)

-- Init Variables
speed = settings.speed
numberOfFlashes = settings.numberOfFlashes
combatAlertCanFade = false
exitCombatAlertCanFade = false
show_background = true

-- Command Line function for showing/hiding UI
local function config(commandline)
  local hs = commandline:match("(%a+)")
  if hs == "hide" then
    configWindow:SetVisible(false)
    print("Configuration window closed.")
    elseif hs == "show" then
    configWindow:SetVisible(true)
    print("Configuration window opened.")
  else
  print("Please us '/alertme hide' or '/alertme show' to show or hide the configuration window.")
 end
end

-- Change the number of Flashes
function nofInput.Event:SliderChange()
  -- nofText:ResizeToText()
  nofText:SetText("Number of Flashes: " .. tostring(nofInput:GetPosition()))
end


-- Save the new variables
function button.Event:LeftPress ()
  numberOfFlashes = nofInput:GetPosition()
  settings.numberOfFlashes = numberOfFlashes
  settings.backgroundOpacity = backgroundOpacity
  settings.show_background = showBackground:GetChecked()
  print("Configuration updated and saved.")
end

-- Exit config window
function exitButton.Event:LeftPress ()
  configWindow:SetVisible(false)
  print("Configuration window closed.")
end


function showCombatAlert()
  alertFrameLeft:SetTexture(settings.ident, settings.combat_left_texture)
  alertFrameRight:SetTexture(settings.ident, settings.combat_right_texture)
  alertFrame:SetBackgroundColor(1,0,0,0)
  if (showBackground:GetChecked() == true) then
    alertFrame:SetBackgroundColor(1,0,0,.1)
    else
    alertFrame:SetBackgroundColor(1,0,0,0)
  end


  nof = settings.numberOfFlashes
  startTime = Inspect.Time.Frame()
  combatAlertCanFade = true
  exitCombatAlertCanFade = false
  direction = true
  alertFrame:SetVisible(true)
end

function showExitCombatAlert()
  alertFrameLeft:SetTexture(settings.ident, settings.exit_combat_left_texture)
  alertFrameRight:SetTexture(settings.ident, settings.exit_combat_right_texture)
  alertFrame:SetBackgroundColor(1,0,0,0)
  if (showBackground:GetChecked() == true) then
    alertFrame:SetBackgroundColor(0,0,1,.1)
    else
    alertFrame:SetBackgroundColor(0,0,1,0)
  end

  nof = settings.numberOfFlashes
  startTime = Inspect.Time.Frame()
  exitCombatAlertCanFade = true
  combatAlertCanFade = false
  alertFrame:SetVisible(true)
  direction = true
end

function resetAlert()
  combatAlertCanFade = false
  exitCombatAlertCanFade = false
  alertFrame:SetVisible(false)
  settings.opacity = 0
end

function updateAnimation()

  currentTime = Inspect.Time.Frame()
  if combatAlertCanFade or exitCombatAlertCanFade then
    if (currentTime - startTime) >= settings.speed and nof > 0 then
          startTime = currentTime

          if (direction) and (nof ~= 0) then
            settings.opacity = settings.opacity + .1
             if (settings.opacity >= .5) then
               direction = false
             end

            elseif not (direction) then
            settings.opacity = settings.opacity - .1
              if(settings.opacity <= 0) then
                direction = true
                nof = nof - 1
              end
          end
      alertFrame:SetAlpha(settings.opacity)


  elseif not exitCombatAlertCanFade and combatAlertCanFade then
        settings.opacity = 0
      end
  end

  if alertFrame:GetHeight() ~= UIParent:GetHeight() and alertFrame:GetWidth() ~= UIParent:GetWidth()  then
        alertFrame:SetHeight(UIParent:GetHeight())
        alertFrame:SetWidth(UIParent:GetWidth())
        print("Resolution has changed. Addon has been resynched.")
    end

end

function saveData()
  numberOfFlashes = settings.numberOfFlashes
  show_background = showBackground:GetChecked()
end

function loadData()
  settings.numberOfFlashes = numberOfFlashes
  nofInput:SetPosition(numberOfFlashes)
  showBackground:SetChecked(show_background)
end



table.insert(Event.System.Update.Begin, {updateAnimation, "AlertMe", "The animation"})
table.insert(Event.System.Secure.Enter, {showCombatAlert, "AlertMe", "Show's the Alert"})
table.insert(Event.System.Secure.Leave, {showExitCombatAlert, "AlertMe", "Show's the Alert"})
table.insert(Command.Slash.Register("alertme"), {config, "AlertMe", "config"})

table.insert(Event.Addon.SavedVariables.Save.Begin, {saveData, "AlertMe", "Save variables"})
table.insert(Event.Addon.SavedVariables.Load.Begin, {loadData, "AlertMe", "Load variables"})